@@ -20,7 +20,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-/* (C) 2013-2020 Graeme Hattan & Bernd Porr */
+/* (C) 2013-2021 Graeme Hattan & Bernd Porr */
 
 #ifndef FIR1_H
 #define FIR1_H
@@ -92,8 +92,8 @@ public:
          * \param input The input sample.
          **/
 	inline double filter(double input) {
-		double *coeff     = coefficients;
-		const double *coeff_end = coefficients + taps;
+		const double *coeff     = coefficients;
+		const double *const coeff_end = coefficients + taps;
 		
 		double *buf_val = buffer + offset;
 		
@@ -159,6 +159,23 @@ public:
          **/
 	void zeroCoeff();
 
+	/**
+	 * Copies the current filter coefficients into a provided array.
+	 * Useful after an adaptive filter has been trained to query
+	 * the result of its training.
+	 * \param coeff_data target where coefficients are copied
+	 * \param number_of_taps number of doubles to be copied
+	 * \throws std::out_of_range number_of_taps is less the actual number of taps.
+	 */
+	void getCoeff(double* coeff_data, unsigned number_of_taps) const;
+
+	/**
+	 * Returns the coefficients as a vector
+	 **/
+	std::vector<double> getCoeffVector() const {
+		return std::vector<double>(coefficients,coefficients+taps);
+	}
+
 	/**
          * Returns the number of taps.
          **/
